#!/usr/bin/env python

"""Include main function to convert Freeplane generated markdown.

License:
    MIT License
    Copyright (c) 2024 François Pelletier
"""

import sys

from markdown_utils import replace_title_with_list


# %% main function


def main():
    """Run the script.

    Args:
        sys.argv (list): list of command line arguments passed to the script.

    Returns:
        str: the processed Markdown text.
    ---

    Examples:
        >>> main()
    ---

    """
    if len(sys.argv) < 3:
        print("Usage: python markdown_to_list.py <depth> <file>")
        sys.exit(1)
    # read file passed as argument
    depth = int(sys.argv[1])
    with open(sys.argv[2], 'r') as my_file:
        text = my_file.read()
    print(replace_title_with_list(text, depth))


if __name__ == '__main__':
    main()
